use bevy::prelude::*;

use crate::components::{Invincible, Player};
use crate::resources::{CurrentStage, FormationState, PlayerLives, Score};
use crate::player::spawn_player_ship; // Import the helper function

// --- Setup ---
pub fn setup(mut commands: Commands) {
    commands.spawn(Camera2dBundle::default());
    spawn_player_ship(&mut commands); // Use helper function from player module
}

// --- Run Conditions ---
pub fn player_exists(query: Query<&Player>) -> bool {
    !query.is_empty()
}

pub fn player_vulnerable(query: Query<&Player, Without<Invincible>>) -> bool {
    !query.is_empty()
}

pub fn should_respawn_player(lives: Res<PlayerLives>, player_query: Query<&Player>) -> bool {
    player_query.is_empty() && lives.count > 0
}

// Moved is_formation_complete to enemy.rs as it's closely related to enemy logic

// --- General Systems ---

// Update Window Title with Lives, Score, and Stage
pub fn update_window_title(
    lives: Res<PlayerLives>,
    score: Res<Score>,
    stage: Res<CurrentStage>, // Add CurrentStage resource
    mut windows: Query<&mut Window>,
) {
    // Update if lives, score, or stage changed
    if lives.is_changed() || score.is_changed() || stage.is_changed() {
        let mut window = windows.single_mut();
        window.title = format!(
            "Galaga :: Stage: {} Lives: {} Score: {}",
            stage.number, lives.count, score.value
        );
    }
}